@@ -1,12 +1,11 @@
 from .dbserver.data_manager import data_manager
-
-
+db_config = None
 class Data(object):
     try:
-        from config.db_config import db_config
+        exec('from config.db_config import db_config')
         if isinstance(db_config,dict):
             Base = data_manager(db_config)
-        print('Auto init successful!')
+        print('Auto init success!')
     except:
         print('Did not find a db config file, need run Data.init(db_config) manually...')
         Base = data_manager(db_config)
